#!/usr/bin/env python3
# -*- coding: utf-8 -*-
#
# SPDX-FileCopyrightText: 2014 Denis Steckelmacher <steckdenis@yahoo.fr>
#
# SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL

from jsgenerator import *
from common import *

# Print the license of the generated file (the same as the one of this file)
license()
basicTypes(globals())
require('event')
require('buffer')

_object = 'new Object()'
_function = 'function(){}'
_buffer = 'new buffer.Buffer()'
_address = '{address: "", family: "", port: 1}'

Module().members(
    F('new Socket', 'createSocket', ('type', _string), ('callback', _function)),
    Class('Socket').prototype('event.EventEmitter').members(
        F(_void, 'send', ('buf', _buffer), ('offset', _int), ('length', _int), ('port', _int), ('address', _string), ('callback', _function)),
        F(_void, 'bind', ('port', _int), ('address', _string), ('callback', _function)),
        F(_void, 'close'),
        F(_address, 'address'),
        F(_void, 'setBroadcast', ('flag', _bool)),
        F(_void, 'setTTL', ('ttl', _int)),
        F(_void, 'setMulticastTTL', ('ttl', _int)),
        F(_void, 'setMulticastLoopback', ('flag', _bool)),
        F(_void, 'addMembership', ('multicastAddress', _string), ('multicastInterface', _string)),
        F(_void, 'dropMembership', ('multicastAddress', _string), ('multicastInterface', _string)),
        F(_void, 'unref'),
        F(_void, 'ref')
    )
).print()



#!/usr/bin/env python3
# -*- coding: utf-8 -*-
#
# SPDX-FileCopyrightText: 2014 Denis Steckelmacher <steckdenis@yahoo.fr>
#
# SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL

from jsgenerator import *
from common import *

# Print the license of the generated file (the same as the one of this file)
license()
basicTypes(globals())

Module().members(
    F(_string, 'normalize', ('p', _string)),
    F(_string, 'join', ('path1', _string), ('path2', _string)),
    F(_string, 'resolve', ('path', _string)),
    F(_string, 'relative', ('from', _string), ('to', _string)),
    F(_string, 'dirname', ('p', _string)),
    F(_string, 'basename', ('p', _string), ('ext', _string)),
    F(_string, 'extname', ('p', _string)),
    Var(_string, 'sep'),
    Var(_string, 'delimiter')
).print()



#!/usr/bin/env python3
# -*- coding: utf-8 -*-
#
# SPDX-FileCopyrightText: 2014 Denis Steckelmacher <steckdenis@yahoo.fr>
#
# SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL

from jsgenerator import *
from common import *

# Print the license of the generated file (the same as the one of this file)
license()
basicTypes(globals())

_object = 'new Object()'

Module().members(
    F(_void, 'log', ('data', _mixed)),
    F(_void, 'info', ('data', _mixed)),
    F(_void, 'error', ('data', _mixed)),
    F(_void, 'warn', ('data', _mixed)),
    F(_void, 'dir', ('obj', _object)),
    F(_void, 'time', ('label', _string)),
    F(_void, 'timeEnd', ('label', _string)),
    F(_void, 'trace', ('label', _string)),
    F(_void, 'assert', ('expression', _bool), ('message', _string))
).print()



#!/usr/bin/env python3
# -*- coding: utf-8 -*-
#
# SPDX-FileCopyrightText: 2014 Denis Steckelmacher <steckdenis@yahoo.fr>
#
# SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL

from jsgenerator import *
from common import *

# Print the license of the generated file (the same as the one of this file)
license()
basicTypes(globals())

_object = 'new Object()'
_function = 'function(){}'
_context = 'new Context()'
_script = 'new Script()'

Module().members(
    F(_mixed, 'runInThisContext', ('code', _string), ('filename', _string)),
    F(_mixed, 'runInNewContext', ('code', _string), ('sandbox', _object), ('filename', _string)),
    F(_mixed, 'runInContext', ('code', _string), ('context', _context), ('filename', _string)),
    F(_context, 'createContext', ('initSandbox', _object)),
    F(_script, 'createScript', ('code', _string), ('filename', _string)),
    Class('Context'),
    Class('Script').members(
        F(_mixed, 'runInThisContext'),
        F(_mixed, 'runInNewContext', ('sandbox', _object))
    )
).print()



#!/usr/bin/env python3
# -*- coding: utf-8 -*-
#
# SPDX-FileCopyrightText: 2014 Denis Steckelmacher <steckdenis@yahoo.fr>
#
# SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL

from jsgenerator import *

# Print the license of the generated file (the same as the one of this file)
print("""/*
    SPDX-FileCopyrightText: 2014 Denis Steckelmacher <steckdenis@yahoo.fr>

    SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
*/
""")

_mixed = '_mixed'       # This variable does not exist and will therefore yield the type "mixed"
_string = '""'
_bool = 'true'
_int = '1'
_float = '1.0'
_array = '[]'
_void = ''

# Fundamental objects (section 19)
_object = 'new Object()'
_function = 'function(){}'
_date = 'new Date()'
_regexp = 'new RegExp()'
_regexp_match = '{index: 1, input: "", length: 1}'
_map = 'new Map()'
_set = 'new Set()'
_arraybuffer = 'new ArrayBuffer()'
_dataview = 'new DataView()'
_iterator = '{next: function() {}, done: true, value: _mixed}'
_promise = 'new Promise()'

Module().members(
Class('Object').members(
    F(_object, 'assign', ('target', _object), ('sources', _mixed)),
    F(_object, 'create', ('O', _object), ('properties', _object)),
    F(_object, 'defineProperties', ('O', _object), ('properties', _object)),
    F(_object, 'defineProperty', ('O', _object), ('property', _string), ('attributes', _object)),
    F(_object, 'freeze', ('O', _object)),
    F(_object, 'getOwnPropertyDescriptor', ('O', _object), ('property', _string)),
    F(_array, 'getOwnPropertyNames', ('O', _object)),
    F(_array, 'getOwnPropertySymbols', ('O', _object)),
    F(_object, 'getPrototypeOf', ('O', _object)),
    F(_bool, 'is', ('a', _mixed), ('b', _mixed)),
    F(_bool, 'isExtensible', ('O', _object)),
    F(_bool, 'isFrozen', ('O', _object)),
    F(_bool, 'isSealed', ('O', _object)),
    F(_iterator, 'keys', ('O', _object)),
    F(_object, 'preventExtensions', ('O', _object)),
    F(_object, 'seal', ('O', _object)),
    F(_object, 'setPrototypeOf', ('O', _object), ('proto', _object)),

    Var(_function, 'constructor'),
    F(_object, 'hasOwnProperty', ('property', _string)),
    F(_bool, 'isPrototypeOf', ('object', _object)),
    F(_bool, 'propertyIsEnumerable', ('property', _string)),
    F(_string, 'toLocaleString'),
    F(_string, 'toString'),
),

Class('Function').members(
    Var(_int, 'length'),
    F(_mixed, 'apply', ('thisArg', _object), ('arguments', _array)),
    F(_function, 'bind', ('thisArg', _object), ('arguments', _mixed)),
    F(_mixed, 'call', ('thisArg', _object), ('arguments', _mixed)),
    F(_function, 'toMethod', ('newHome', _object), ('methodName', _string)),
    Var(_string, 'name')
),

Class('Boolean', ('value', _bool)).members(
    F(_bool, 'valueOf'),
),

# 19.4 (Symbol) skipped for now because it is far too internal
Class('Error', ('message', _string)).members(
    Var(_string, 'message'),
    Var(_string, 'name'),
),

Class('EvalError').prototype('Error'),
Class('RangeError').prototype('Error'),
Class('ReferenceError').prototype('Error'),
Class('SyntaxError').prototype('Error'),
Class('TypeError').prototype('Error'),
Class('URIError').prototype('Error'),

# 19.5.6 (NativeError) skipped because it seems too internal

# Numbers and dates (section 20)
Class('Number', ('value', _float)).members(
    Var(_float, 'EPSILON'),
    F(_bool, 'isFinite', ('number', _float)),
    F(_bool, 'isInteger', ('number', _int)),
    F(_bool, 'isNaN', ('number', _float)),
    F(_bool, 'isSafeInteger', ('number', _int)),
    Var(_int, 'MAX_SAFE_INTEGER'),
    Var(_float, 'MAX_VALUE'),
    Var(_float, 'NaN'),
    Var(_float, 'NEGATIVE_INFINITY'),
    Var(_int, 'MIN_SAFE_INTEGER'),
    Var(_float, 'MIN_VALUE'),
    F(_float, 'parseFloat', ('string', _string)),
    F(_int, 'parseInt', ('string', _string), ('radix', _int)),
    Var(_float, 'POSITIVE_INFINITY'),
    F(_string, 'toExponential', ('fractionDigits', _int)),
    F(_string, 'toFixed', ('fractionDigits', _int)),
    F(_string, 'toPrecision', ('precision', _int)),
    F(_float, 'valueOf'),
),

Struct('Math').members(
    Var(_float, 'E'),
    Var(_float, 'LN10'),
    Var(_float, 'LOG10E'),
    Var(_float, 'LN2'),
    Var(_float, 'PI'),
    Var(_float, 'SQRT1_2'),
    Var(_float, 'SQRT2'),
    F(_float, 'abs', ('x', _float)),
    F(_float, 'acos', ('x', _float)),
    F(_float, 'acosh', ('x', _float)),
    F(_float, 'asin', ('x', _float)),
    F(_float, 'asinh', ('x', _float)),
    F(_float, 'atan', ('x', _float)),
    F(_float, 'atanh', ('x', _float)),
    F(_float, 'atan2', ('x', _float), ('y', _float)),
    F(_float, 'cbrt', ('x', _float)),
    F(_int, 'ceil', ('x', _float)),
    F(_int, 'clz32', ('x', _int)),
    F(_float, 'cos', ('x', _float)),
    F(_float, 'cosh', ('x', _float)),
    F(_float, 'exp', ('x', _float)),
    F(_float, 'expm1', ('x', _float)),
    F(_int, 'floor', ('x', _float)),
    F(_int, 'fround', ('x', _float)),
    F(_float, 'hypot', ('a', _float), ('b', _float)),
    F(_int, 'imul', ('x', _int), ('y', _int)),
    F(_float, 'log', ('x', _float)),
    F(_float, 'log1p', ('x', _float)),
    F(_float, 'log10', ('x', _float)),
    F(_float, 'log2', ('x', _float)),
    F(_float, 'max', ('a', _float), ('b', _float)),
    F(_float, 'min', ('a', _float), ('b', _float)),
    F(_float, 'pow', ('x', _float), ('y', _float)),
    F(_float, 'random'),
    F(_int, 'round', ('x', _float)),
    F(_int, 'sign', ('x', _float)),
    F(_float, 'sin', ('x', _float)),
    F(_float, 'sinh', ('x', _float)),
    F(_float, 'sqrt', ('x', _float)),
    F(_float, 'tan', ('x', _float)),
    F(_float, 'tanh', ('x', _float)),
    F(_int, 'trunc', ('x', _float)),
),

Class('Date', ('year', _int), ('month', _int), ('date', _int), ('hours', _int), ('minutes', _int), ('seconds', _int), ('ms', _int)).members(
    F(_date, 'now'),
    F(_date, 'parse', ('string', _string)),
    F(_date, 'UTC', ('year', _int), ('month', _int), ('date', _int), ('hours', _int), ('minutes', _int), ('seconds', _int), ('ms', _int)),
    F(_int, 'getDate'),
    F(_int, 'getDay'),
    F(_int, 'getFullYear'),
    F(_int, 'getHours'),
    F(_int, 'getMilliseconds'),
    F(_int, 'getMinutes'),
    F(_int, 'getMonth'),
    F(_int, 'getSeconds'),
    F(_int, 'getTime'),
    F(_int, 'getTimezoneOffset'),
    F(_int, 'getUTCDate'),
    F(_int, 'getUTCDay'),
    F(_int, 'getUTCFullYear'),
    F(_int, 'getUTCHours'),
    F(_int, 'getUTCMilliseconds'),
    F(_int, 'getUTCMinutes'),
    F(_int, 'getUTCMonth'),
    F(_int, 'getUTCSeconds'),
    F(_int, 'setDate', ('date', _int)),
    F(_int, 'setFullYear', ('year', _int), ('month', _int), ('date', _int)),
    F(_int, 'setHours', ('hours', _int), ('minutes', _int), ('seconds', _int), ('ms', _int)),
    F(_int, 'setMilliseconds', ('ms', _int)),
    F(_int, 'setMinutes', ('min', _int), ('sec', _int), ('ms', _int)),
    F(_int, 'setMonth', ('month', _int), ('date', _int)),
    F(_int, 'setSeconds', ('sec', _int), ('ms', _int)),
    F(_int, 'setTime', ('time', _int)),
    F(_int, 'setUTCDate', ('date', _int)),
    F(_int, 'setUTCFullYear', ('year', _int), ('month', _int), ('date', _int)),
    F(_int, 'setUTCHours', ('hours', _int), ('minutes', _int), ('seconds', _int), ('ms', _int)),
    F(_int, 'setUTCMilliseconds', ('ms', _int)),
    F(_int, 'setUTCMinutes', ('min', _int), ('sec', _int), ('ms', _int)),
    F(_int, 'setUTCMonth', ('month', _int), ('date', _int)),
    F(_int, 'setUTCSeconds', ('sec', _int), ('ms', _int)),
    F(_string, 'toDateString'),
    F(_string, 'toISOString'),
    F(_string, 'toJSON', ('key', _string)),
    F(_string, 'toLocaleDateString'),
    F(_string, 'toLocaleTimeString'),
    F(_string, 'toTimeString'),
    F(_string, 'toUTCString'),
    F(_int, 'valueOf'),
),

# Text Processing (section 21)
Class('String', ('value', _mixed)).members(
    F(_string, 'fromCharCode', ('code', _int)),
    F(_string, 'fromCodePoint', ('code', _int)),
    F(_string, 'raw', ('callSize', _mixed)),
    F(_string, 'charAt', ('pos', _int)),
    F(_int, 'charCodeAt', ('pos', _int)),
    F(_int, 'codePointAt', ('pos', _int)),
    F(_string, 'concat', ('other', _string)),
    F(_bool, 'contains', ('searchString', _string), ('position', _int)),
    F(_bool, 'endsWith', ('searchString', _string), ('endPosition', _int)),
    F(_int, 'indexOf', ('searchString', _string), ('position', _int)),
    F(_int, 'lastIndexOf', ('searchString', _string), ('position', _int)),
    F(_int, 'localeCompare', ('other', _string)),
    F(_regexp_match, 'match', ('regexp', _regexp)),
    F(_string, 'normalize', ('form', _string)),
    F(_string, 'repeat', ('count', _int)),
    F(_string, 'replace', ('searchValue', _string), ('replaceValue', _string)),
    F(_int, 'search', ('regexp', _regexp)),
    F(_string, 'slice', ('start', _int), ('end', _int)),
    F(_array, 'split', ('separator', _string), ('limit', _int)),
    F(_bool, 'startsWith', ('searchString', _string), ('position', _int)),
    F(_string, 'substring', ('start', _int), ('end', _int)),
    F(_string, 'toLocaleLowerCase'),
    F(_string, 'toLocaleUpperCase'),
    F(_string, 'toLowerCase'),
    F(_string, 'toUpperCase'),
    F(_string, 'trim'),
    F(_string, 'valueOf'),
    Var(_int, 'length'),
),

Class('RegExp', ('pattern', _string), ('flags', _string)).members(
    F(_void, 'compile'),
    F(_array, 'exec', ('string', _string)),
    Var(_bool, 'ingoreCase'),
    F(_regexp_match, 'match', ('string', _string)),
    Var(_bool, 'multiline'),
    F(_string, 'replace', ('string', _string), ('replaceValue', _string)),
    F(_int, 'search', ('string', _string)),
    Var(_string, 'source'),
    F(_array, 'split', ('string', _string), ('limit', _int)),
    Var(_bool, 'sticky'),
    F(_bool, 'test', ('string', _string)),
    Var(_bool, 'unicode'),
    Var(_int, 'lastIndex'),
    Var(_string, 'lastMatch'),
),

# Array Objects (section 22)
Class('Array', ('len', _int)).members(
    F(_array, 'from', ('arrayLike', _mixed), ('mapfn', _function), ('thisArg', _object)),
    F(_bool, 'isArray', ('arg', _mixed)),
    F(_array, 'of', ('items', _mixed)),
    F(_array, 'concat', ('other', _array)),
    F(_array, 'copyWithin', ('target', _int), ('start', _int), ('end', _int)),
    F(_iterator, 'entries'),
    F(_bool, 'every', ('callbackfn', _function), ('thisArg', _object)),
    F(_array, 'fill', ('value', _mixed), ('start', _int), ('end', _int)),
    F(_array, 'filter', ('callbackfn', _function), ('thisArg', _object)),
    F(_mixed, 'find', ('predicate', _function), ('thisArg', _object)),
    F(_int, 'findIndex', ('predicate', _function), ('thisArg', _object)),
    F(_void, 'forEach', ('callbackfn', _function), ('thisArg', _object)),
    F(_int, 'indexOf', ('searchElement', _mixed), ('fromIndex', _int)),
    F(_string, 'join', ('separator', _string)),
    F(_int, 'lastIndexOf', ('searchElement', _mixed), ('fromIndex', _int)),
    F(_array, 'map', ('callbackfn', _function), ('thisArg', _object)),
    F(_mixed, 'pop'),
    F(_int, 'push', ('element', _mixed)),
    F(_mixed, 'reduce', ('callbackfn', _function), ('initialValue', _mixed)),
    F(_mixed, 'reduceRight', ('callbackfn', _function), ('initialValue', _mixed)),
    F(_array, 'reverse'),
    F(_mixed, 'shift'),
    F(_array, 'slice', ('start', _int), ('end', _int)),
    F(_bool, 'some', ('callbackfn', _function), ('thisArg', _object)),
    F(_array, 'sort', ('comparefn', _function)),
    F(_array, 'splice', ('start', _int), ('deleteCount', _int), ('items', _mixed)),
    F(_string, 'substr', ('start', _int), ('length', _int)),
    F(_int, 'unshift', ('items', _mixed)),
    F(_iterator, 'values'),
    Var(_int, 'length'),
),

# Keyed Collection (section 23)
Class('Map', ('iterable', _mixed)).members(
    F(_void, 'clear'),
    F(_bool, 'delete', ('key', _mixed)),
    F(_iterator, 'entries'),
    F(_void, 'forEach', ('callbackfn', _function), ('thisArg', _object)),
    F(_mixed, 'get', ('key', _mixed)),
    F(_bool, 'has', ('key', _mixed)),
    F(_map, 'set', ('key', _mixed), ('value', _mixed)),
    Var(_int, 'size'),
    F(_iterator, 'values'),
),

Class('Set', ('iterable', _mixed)).members(
    F(_set, 'add', ('value', _mixed)),
    F(_void, 'clear'),
    F(_bool, 'delete', ('value', _mixed)),
    F(_iterator, 'entries'),
    F(_void, 'forEach', ('callbackfn', _function), ('thisArg', _object)),
    F(_bool, 'has', ('value', _mixed)),
    Var(_int, 'size'),
    F(_iterator, 'values'),
),

Class('WeakMap', ('iterable', _mixed)).members(
    F(_void, 'clear'),
    F(_bool, 'delete', ('key', _mixed)),
    F(_mixed, 'get', ('key', _mixed)),
    F(_bool, 'has', ('key', _mixed)),
    F(_map, 'set', ('key', _mixed), ('value', _mixed)),
),

Class('WeakSet', ('iterable', _mixed)).members(
    F(_set, 'add', ('value', _mixed)),
    F(_void, 'clear'),
    F(_bool, 'delete', ('value', _mixed)),
    F(_bool, 'has', ('value', _mixed)),
),

# Structured Data (section 24)
Class('ArrayBuffer', ('length', _int)).members(
    F(_bool, 'isView', ('arg', _mixed)),
    Var(_int, 'byteLength'),
    F(_arraybuffer, 'slice', ('start', _int), ('end', _int)),
),

Class('DataView', ('buffer', _arraybuffer), ('byteOffset', _int), ('byteLength', _int)).members(
    Var(_dataview, 'buffer'),
    Var(_int, 'byteLength'),
    Var(_int, 'byteOffset'),
    F(_float, 'getFloat32', ('byteOffset', _int), ('littleEndian', _bool)),
    F(_float, 'getFloat64', ('byteOffset', _int), ('littleEndian', _bool)),
    F(_int, 'getInt8', ('byteOffset', _int)),
    F(_int, 'getInt16', ('byteOffset', _int), ('littleEndian', _bool)),
    F(_int, 'getInt32', ('byteOffset', _int), ('littleEndian', _bool)),
    F(_int, 'getUInt8', ('byteOffset', _int)),
    F(_int, 'getUInt16', ('byteOffset', _int), ('littleEndian', _bool)),
    F(_int, 'getUInt32', ('byteOffset', _int), ('littleEndian', _bool)),
    F(_void, 'setFloat32', ('byteOffset', _int), ('value', _float), ('littleEndian', _bool)),
    F(_void, 'setFloat64', ('byteOffset', _int), ('value', _float), ('littleEndian', _bool)),
    F(_void, 'setInt8', ('byteOffset', _int), ('value', _int)),
    F(_void, 'setInt16', ('byteOffset', _int), ('value', _int), ('littleEndian', _bool)),
    F(_void, 'setInt32', ('byteOffset', _int), ('value', _int), ('littleEndian', _bool)),
    F(_void, 'setUInt8', ('byteOffset', _int), ('value', _int)),
    F(_void, 'setUInt16', ('byteOffset', _int), ('value', _int), ('littleEndian', _bool)),
    F(_void, 'setUInt32', ('byteOffset', _int), ('value', _int), ('littleEndian', _bool)),
),

Struct('JSON').members(
    F(_mixed, 'parse', ('text', _string), ('reviver', _function)),
    F(_string, 'stringify', ('value', _mixed), ('replacer', _function), ('space', _string)),
),

# Control Abstraction Objects (section 25)
Class('Promise', ('executor', _function)).members(
    F(_void, 'all', ('iterable', _array)),
    F(_void, 'race', ('iterable', _array)),
    F(_promise, 'resolve', ('x', _mixed)),
    F(_void, 'catch', ('onRejected', _function)),
    F(_void, 'then', ('onFulfilled', _function), ('onRejected', _function)),
),

Struct('Reflect').members(
    F(_mixed, 'apply', ('target', _function), ('thisArgument', _object), ('argumentList', _array)),
    F(_object, 'construct', ('target', _function), ('argumentList', _array)),
    F(_void, 'deleteProperty', ('target', _object), ('propertyKey', _string)),
    F(_iterator, 'enumerate', ('target', _object)),
    F(_mixed, 'get', ('target', _object), ('propertyKey', _string), ('receiver', _object)),
    F(_bool, 'has', ('target', _object), ('propertyKey', _string)),
    F(_array, 'ownKeys', ('target', _object)),
    F(_void, 'set', ('target', _object), ('propertyKey', _string), ('value', _mixed), ('receiver', _object)),
),

*[Class(a + 'Array', ('length', _int)).prototype('Array').members(
    Var(_mixed, 'buffer'),
    Var(_int, 'byteLength'),
    Var(_int, 'byteOffset'),
    F(_array, 'subarray', ('begin', _int), ('end', _int)),
    Var(_int, 'BYTES_PER_ELEMENT'),
) for a in ['Int8', 'Uint8', 'Uint8Clamped', 'Int16', 'Uint16', 'Int32', 'Uint32', 'Float32', 'Float64']]
).print()
# Realm, Loader and Proxy not decribed for now



{% load kdev_filters %}
{% block license_header %}
{% if license %}
#

 {{ license|lines_prepend:"# " }}
#
{% endif %}
{% endblock license_header %}


import unittest


class {{ name }}(unittest.TestCase):
    def setUp(self):
        # Called prior to each test method
        pass


    def tearDown(self):
        # Called after each test method
        pass


    {% for case in testCases %}
    def test_{{ case }}(self):
        pass


    {% endfor %}


if __name__ == "__main__":
    unittest.main()



#!/usr/bin/env python3
# -*- coding: utf-8 -*-
#
# SPDX-FileCopyrightText: 2014 Denis Steckelmacher <steckdenis@yahoo.fr>
#
# SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL

from jsgenerator import *
from common import *

# Print the license of the generated file (the same as the one of this file)
license()
basicTypes(globals())
require('event')

_function = 'function(){}'
_object = 'new Object()'
_date = 'new Date()'
_socket = 'new Socket()'
_server = 'new Server()'
_address = '{port: 1, family: "", address: ""}'

Module().members(
    F(_server, 'createServer', ('options', _object), ('connectionListener', _function)),
    F(_socket, 'connect', ('options', _object), ('connectionListener', _function)),
    F(_socket, 'createConnection', ('options', _object), ('connectionListener', _function)),
    Class('Server').prototype('event.EventEmitter').members(
        F(_void, 'listen', ('port', _int), ('host', _string), ('backlog', _int), ('callback', _function)),
        F(_void, 'close', ('callback', _function)),
        F(_address, 'address'),
        F(_void, 'unref'),
        F(_void, 'ref'),
        Var(_int, 'maxConnections'),
        Var(_int, 'connections'),
        F(_void, 'getConnections', ('callback', _function))
    ),
    Class('Socket', ('options', _object)).prototype('event.EventEmitter').members(
        F(_void, 'connect', ('port', _int), ('host', _string), ('connectionListener', _function)),
        Var(_int, 'bufferSize'),
        F(_void, 'setEncoding', ('encoding', _string)),
        F(_void, 'write', ('data', _string), ('encoding', _string), ('callback', _function)),
        F(_void, 'end', ('data', _string), ('encoding', _string)),
        F(_void, 'destroy'),
        F(_void, 'pause'),
        F(_void, 'resume'),
        F(_void, 'setTimeout', ('timeout', _int), ('callback', _function)),
        F(_void, 'setNoDelay', ('noDelay', _bool)),
        F(_void, 'setKeepAlive', ('enable', _bool), ('initialDelay', _int)),
        F(_address, 'address'),
        F(_void, 'unref'),
        F(_void, 'ref'),
        Var(_string, 'remoteAddress'),
        Var(_int, 'remotePort'),
        Var(_string, 'localAddress'),
        Var(_int, 'localPort'),
        Var(_int, 'bytesRead'),
        Var(_int, 'bytesWritten')
    ),
    F(_int, 'isIP', ('input', _string)),
    F(_bool, 'isIPv4', ('input', _string)),
    F(_bool, 'isIPv6', ('input', _string))
).print()



#!/usr/bin/env python3
# -*- coding: utf-8 -*-
#
# SPDX-FileCopyrightText: 2014 Denis Steckelmacher <steckdenis@yahoo.fr>
#
# SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL

from jsgenerator import *
from common import *

# Print the license of the generated file (the same as the one of this file)
license()
basicTypes(globals())

_object = 'new Object()'
_function = 'new Function()'

Module().members(
    F(_string, 'stringify', ('object', _object), ('sep', _string), ('eq', _string)),
    F(_object, 'parse', ('str', _string), ('sep', _string), ('eq', _string), ('options', _object)),
    Var(_function, 'escape'),
    Var(_function, 'unescape')
).print()



#!/usr/bin/env python3
#
# Downloads color schemes from download.kde.org and installs them into the desired prefix
# Usage: install_colorschemes.py [INSTALL_DIR]

import distutils.dir_util
import os
import shutil
import sys
import tarfile
import urllib.request

installDir = sys.argv[1] if len(sys.argv) > 1 else None
ver = "5.13.4" # Plasma version
colorSchemesDir = "color-schemes"

def downloadAndExtract(url, extractPath):
    fname = os.path.basename(url)
    if not os.path.exists(fname):
        print("Downloading {0}".format(url))
        urllib.request.urlretrieve(url, fname)
    else:
        print("Skipping download of {0} (file already exists)".format(url))

    print("Unpacking {0}".format(fname))
    dirname = fname.replace(".tar.xz", "")
    shutil.rmtree(dirname, ignore_errors=True)
    with tarfile.open(fname) as tar:
        for tarinfo in tar.getmembers():
            if tarinfo.name.startswith(extractPath):
                tarinfo.name = os.path.basename(tarinfo.name) # remove the path by reset it
                tar.extract(member=tarinfo, path=colorSchemesDir)

downloadAndExtract('https://download.kde.org/stable/plasma/{0}/breeze-{0}.tar.xz'.format(ver),
                   "breeze-{0}/colors/".format(ver))
downloadAndExtract('https://download.kde.org/stable/plasma/{0}/plasma-desktop-{0}.tar.xz'.format(ver),
                   "plasma-desktop-{0}/kcms/colors/schemes/".format(ver))

# Cleanup
os.remove(os.path.join(colorSchemesDir, "CMakeLists.txt"))

print("Available color schemes: {0}".format(", ".join(os.listdir(colorSchemesDir))))

if installDir:
    print("Installing to: {0}".format(installDir))
    distutils.dir_util.copy_tree(colorSchemesDir, os.path.join(installDir, colorSchemesDir))



#!/usr/bin/env python3
# -*- coding: utf-8 -*-
#
# SPDX-FileCopyrightText: 2014 Denis Steckelmacher <steckdenis@yahoo.fr>
#
# SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL

from jsgenerator import *
from common import *

# Print the license of the generated file (the same as the one of this file)
license()
basicTypes(globals())
require('event')

_object = 'new Object()'
_childprocess = 'new ChildProcess()'
_stream = 'new stream.Stream()'

Module().members(
    Class('ChildProcess').prototype('event.EventEmitter').members(
        Var(_stream, 'stdin'),
        Var(_stream, 'stdout'),
        Var(_stream, 'stderr'),
        Var(_int, 'pid'),
        Var(_bool, 'connected'),
        F(_void, 'kill', ('signal', _string)),
        F(_void, 'send', ('message', _object), ('sendHandle', _object)),
        F(_void, 'disconnect'),
    ),
    F(_childprocess, 'spawn', ('command', _string), ('args', _array), ('options', _object)),
    F(_childprocess, 'exec', ('command', _string), ('args', _array), ('callback', 'function(){}')),
    F(_childprocess, 'execFile', ('file', _string), ('args', _array), ('options', _object), ('callback', 'function(){}')),
    F(_childprocess, 'fork', ('modulePath', _string), ('args', _array), ('options', _object))
).print()



#!/usr/bin/env python3
# -*- coding: utf-8 -*-
#
# SPDX-FileCopyrightText: 2014 Denis Steckelmacher <steckdenis@yahoo.fr>
#
# SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL

from jsgenerator import *
from common import *

# Print the license of the generated file (the same as the one of this file)
license()
basicTypes(globals())
require('stream')
require('event')

_object = 'new Object()'
_function = 'function(){}'
_stream = 'new stream.Writable()'

Module().members(
    F('new Interface()', 'createInterface', ('options', _object)),
    Class('Interface').prototype('event.EventEmitter').members(
        F(_void, 'setPrompt', ('prompt', _string), ('length', _int)),
        F(_void, 'prompt', ('preserveCursor', _bool)),
        F(_void, 'question', ('query', _string), ('callback', _function)),
        F(_void, 'pause'),
        F(_void, 'resume'),
        F(_void, 'close'),
        F(_void, 'write', ('data', _string), ('key', _object))
    ),
    F(_void, 'cursorTo', ('stream', _stream), ('x', _int), ('y', _int)),
    F(_void, 'moveCursor', ('stream', _stream), ('dx', _int), ('dy', _int)),
    F(_void, 'clearLine', ('stream', _stream), ('dir', _int)),
    F(_void, 'clearScreenDown', ('stream', _stream))
).print()
